/*     */ package org.apache.batik.parser;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.Reader;
/*     */ import java.util.Locale;
/*     */ import java.util.MissingResourceException;
/*     */ import org.apache.batik.i18n.LocalizableSupport;
/*     */ import org.apache.batik.util.io.NormalizingReader;
/*     */ import org.apache.batik.util.io.StreamNormalizingReader;
/*     */ import org.apache.batik.util.io.StringNormalizingReader;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractParser
/*     */   implements Parser
/*     */ {
/*     */   public static final String BUNDLE_CLASSNAME = "org.apache.batik.parser.resources.Messages";
/*  50 */   protected ErrorHandler errorHandler = new DefaultErrorHandler();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  55 */   protected LocalizableSupport localizableSupport = new LocalizableSupport("org.apache.batik.parser.resources.Messages", AbstractParser.class.getClassLoader());
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected NormalizingReader reader;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int current;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  73 */   public int getCurrent() { return this.current; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  80 */   public void setLocale(Locale l) { this.localizableSupport.setLocale(l); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  87 */   public Locale getLocale() { return this.localizableSupport.getLocale(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  96 */   public String formatMessage(String key, Object[] args) throws MissingResourceException { return this.localizableSupport.formatMessage(key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 112 */   public void setErrorHandler(ErrorHandler handler) { this.errorHandler = handler; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void parse(Reader r) throws ParseException {
/*     */     try {
/* 120 */       this.reader = new StreamNormalizingReader(r);
/* 121 */       doParse();
/*     */     } catch (IOException e) {
/* 123 */       this.errorHandler.error(new ParseException(createErrorMessage("io.exception", null), e));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void parse(InputStream is, String enc) throws ParseException {
/*     */     try {
/* 135 */       this.reader = new StreamNormalizingReader(is, enc);
/* 136 */       doParse();
/*     */     } catch (IOException e) {
/* 138 */       this.errorHandler.error(new ParseException(createErrorMessage("io.exception", null), e));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void parse(String s) throws ParseException {
/*     */     try {
/* 149 */       this.reader = new StringNormalizingReader(s);
/* 150 */       doParse();
/*     */     } catch (IOException e) {
/* 152 */       this.errorHandler.error(new ParseException(createErrorMessage("io.exception", null), e));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 172 */   protected void reportError(String key, Object[] args) throws ParseException { this.errorHandler.error(new ParseException(createErrorMessage(key, args), this.reader.getLine(), this.reader.getColumn())); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 185 */   protected void reportCharacterExpectedError(char expectedChar, int currentChar) { reportError("character.expected", new Object[] { new Character(expectedChar), new Integer(currentChar) }); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 198 */   protected void reportUnexpectedCharacterError(int currentChar) { reportError("character.unexpected", new Object[] { new Integer(currentChar) }); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected String createErrorMessage(String key, Object[] args) throws MissingResourceException {
/*     */     try {
/* 210 */       return formatMessage(key, args);
/*     */     } catch (MissingResourceException e) {
/* 212 */       return key;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 221 */   protected String getBundleClassName() { return "org.apache.batik.parser.resources.Messages"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void skipSpaces() {
/*     */     while (true) {
/* 229 */       switch (this.current) {
/*     */         default:
/*     */           return;
/*     */         case 9:
/*     */         case 10:
/*     */         case 13:
/*     */         case 32:
/*     */           break;
/* 237 */       }  this.current = this.reader.read();
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void skipCommaSpaces() {
/*     */     while (true) {
/* 246 */       switch (this.current) {
/*     */         default:
/*     */           break;
/*     */         case 9:
/*     */         case 10:
/*     */         case 13:
/*     */         case 32:
/*     */           break;
/* 254 */       }  this.current = this.reader.read();
/*     */     } 
/* 256 */     if (this.current == 44)
/*     */       while (true) {
/* 258 */         switch (this.current = this.reader.read()) {
/*     */           case 9:
/*     */           case 10:
/*     */           case 13:
/*     */           case 32:
/*     */             break;
/*     */         } 
/*     */       }  
/*     */   }
/*     */   
/*     */   protected abstract void doParse();
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-parser.jar!\org\apache\batik\parser\AbstractParser.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */