/*     */ package org.apache.batik.parser;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.Reader;
/*     */ import org.apache.batik.util.io.NormalizingReader;
/*     */ import org.apache.batik.util.io.StreamNormalizingReader;
/*     */ import org.apache.batik.util.io.StringNormalizingReader;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractScanner
/*     */ {
/*     */   protected NormalizingReader reader;
/*     */   protected int current;
/*  51 */   protected char[] buffer = new char[128];
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int position;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int type;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int previousType;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int start;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int end;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int blankCharacters;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AbstractScanner(Reader r) throws ParseException {
/*     */     try {
/*  90 */       this.reader = new StreamNormalizingReader(r);
/*  91 */       this.current = nextChar();
/*     */     } catch (IOException e) {
/*  93 */       throw new ParseException(e);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AbstractScanner(InputStream is, String enc) throws ParseException {
/*     */     try {
/* 104 */       this.reader = new StreamNormalizingReader(is, enc);
/* 105 */       this.current = nextChar();
/*     */     } catch (IOException e) {
/* 107 */       throw new ParseException(e);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public AbstractScanner(String s) throws ParseException {
/*     */     try {
/* 117 */       this.reader = new StringNormalizingReader(s);
/* 118 */       this.current = nextChar();
/*     */     } catch (IOException e) {
/* 120 */       throw new ParseException(e);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 128 */   public int getLine() { return this.reader.getLine(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 135 */   public int getColumn() { return this.reader.getColumn(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 142 */   public char[] getBuffer() { return this.buffer; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 149 */   public int getStart() { return this.start; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 156 */   public int getEnd() { return this.end; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void clearBuffer() {
/* 163 */     if (this.position <= 0) {
/* 164 */       this.position = 0;
/*     */     } else {
/* 166 */       this.buffer[0] = this.buffer[this.position - 1];
/* 167 */       this.position = 1;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 175 */   public int getType() { return this.type; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 182 */   public String getStringValue() { return new String(this.buffer, this.start, this.end - this.start); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public int next() {
/* 189 */     this.blankCharacters = 0;
/* 190 */     this.start = this.position - 1;
/* 191 */     this.previousType = this.type;
/* 192 */     nextToken();
/* 193 */     this.end = this.position - endGap();
/* 194 */     return this.type;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract int endGap();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected abstract void nextToken();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 211 */   protected static boolean isEqualIgnoreCase(int i, char c) { return (i == -1) ? false : ((Character.toLowerCase((char)i) == c)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected int nextChar() {
/* 219 */     this.current = this.reader.read();
/*     */     
/* 221 */     if (this.current == -1) {
/* 222 */       return this.current;
/*     */     }
/*     */     
/* 225 */     if (this.position == this.buffer.length) {
/* 226 */       char[] t = new char[1 + this.position + this.position / 2];
/* 227 */       System.arraycopy(this.buffer, 0, t, 0, this.position);
/* 228 */       this.buffer = t;
/*     */     } 
/*     */     
/* 231 */     this.buffer[this.position++] = (char)this.current; return (char)this.current;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-parser.jar!\org\apache\batik\parser\AbstractScanner.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */